%
% Shows some examples how to analyse a given root system using getMap.
%
% See also: getMap, Example_Maize.
%
% Copyright 2008-2009 Daniel Leitner. See license.txt for details.
% 

Example_Maize; %creates a root system

N=length(slides); 
bnd = getBounds(slides{N});

%
% Example 1
%
x = ( bnd(1)+bnd(2) )/2;
y = ( bnd(3)+bnd(4) )/2;
z = linspace(bnd(5),bnd(6),100);

[map,l] = getMap(slides{N},x,y,z,'l');

d = 1:size(map,3);
d(:) = map(1,1,:);

figure;
plot(d/l,z(1:length(d)));
ylabel('depth (cm)');
xlabel('root length fraction');

%
% Example 2
%
x = linspace(bnd(1),bnd(2),30);
y = (bnd(3)+bnd(4))/2;
z = linspace(bnd(5),bnd(6),60);
map = getMap(slides{N},x,y,z,'s');

d = zeros(size(map,1),size(map,3));
d(:,:) = map(:,1,:);

figure;
d2=(d').*0.75; % change contrast
z2 = z(end:-1:1);
imagesc(x,z2,d2);
title('Root surface distribution')
 
% 
% Example 3
%
showSlides(slides);

x = linspace(bnd(1),bnd(2),30); 
y = linspace(bnd(3),bnd(4),3);
z = linspace(bnd(5),bnd(6),60);
map = getMap(slides{N},x,y,z);

m=zeros(size(map,2),size(map,1),size(map,3));
for i = 1: size(map,1)
    for j = 1: size(map,2)
        m(j,i,:) = map(i,j,:);
    end
end
slice(x,y,z,m,[],0,[]);

%view(0,0);
%axis(bnd);
lighting none;
shading flat;
view(3);


% Example 4
%
N=1;
showSlides(slides);
bnd = getBounds(slides{N});

x = linspace(bnd(1),bnd(2),30);
y = linspace(bnd(3),bnd(4),30);
z = linspace(bnd(5),bnd(6),60);
map = getMap(slides{N},x,y,z);

m=zeros(size(map,2),size(map,1),size(map,3));
for i = 1: size(map,1)
    for j = 1: size(map,2)
        m(j,i,:) = map(i,j,:);
    end
end

z0 = bnd(5);
z1 = bnd(6)-bnd(5);
slice(x,y,z,m,[],[],[ z0+0.25*z1, z0+0.5*z1, z0+0.75*z1 ]);
lighting none;
shading flat
view(3);






