%
% The example demonstrates the use of createRootSystem and
% ruleGravitropism. Different subplots for parameters N and sigma are
% created. 
% 
% See also: ruleGravitropismN, createRootSystem, Example_initialRoots1.
%
% Copyright 2008-2009 Daniel Leitner. See license.txt for details.
%
clear all;

% Create a 0th order root of 30 cm length and 0.05 cm radius
p{1}.r  = 2;
p{1}.rs = 0;
p{1}.k  = 30;
p{1}.ks = 0;
p{1}.a  = 0.05;
p{1}.as = 0;
p{1}.color = [200/255,200/255,10/255];

% Parameters for ruleGravitropism:
p{1}.sigma = 0;            %random deflection
p{1}.exp=0;                %exponent

for j=1:4
    p{1}.sigma = j * pi/45;
    for i = 1:3
        p{1}.N = i-1;
        root{i,j} = createBranchedRoot(p, 0.5);
    end
end

figure;

for j=1:4
    for i = 1:3
        % create a root system out of the order 0 root
        e = 0.5;
        r = 5;
        number=50; % 100,200
        rootsystem = createRootSystem(root{i,j},number,r,e);

        % show results after 20 days        
        slides = simulate(rootsystem,20,1);
        subplot(4,3,3*(j-1)+i)                
        showSlides(slides,0);
        title(['N= ' num2str(i-1) ', \sigma= ' num2str(j * pi/45) ]);
    end
end

