%
% An idealized Maize root system using parameters from literature.
%
% The parameters are given for each order of the root system:
% r:            initial growth rate (cm/day)
% la, lb, ln:   length of apical, basal and inter-root distance (cm)
% nob:          number of lateral branches (-)
% k:            maximal length (for highest order roots only instead of la,
%       lb, ln, nob) (cm)
% a:            radius (cm)
% theta:        angle between root and later root of next order (-)
% color:        color of the root (RGB)
% N:            strength of gravitropism (-)
% sigma:        additional random noise to the heading (cm-1)
% bend:         an arbitrary deflection rule (instead of N and sigma)
%       (Matlab function) 
%
% An additional s in the name denotes the standard deviation of each
% parameter.
%
% See also: createBranchedRoot, createRootSystem, Example_SingleMaizeRoot.
%
% Copyright 2008-2009 Daniel Leitner. See license.txt for details.
%


clear all;

% % 2nd Order 
% p{3}.r  = 1.5;                       
% p{3}.rs = 0.15;                      
% p{3}.k  = 0.2;                    
% p{3}.ks = 0.02;            
% p{3}.a  = 0.01;                
% p{3}.as = 0;                   
% p{3}.theta = 68*pi/180;        
% p{3}.thetas = 3*pi/180;  
% p{3}.color = [200/255,200/255,10/255];  
% p{3}.N = 0;                         
% p{3}.sigma = 40*pi/180;
% % 1st Order
p{2}.r = 6.4;
p{2}.rs = 0.64;
p{2}.lb = 0.7;    
p{2}.lbs = 0.07;               
p{2}.la = 2.7;            
p{2}.las = 0.27;                     
p{2}.ln = 0.7;               
p{2}.lns = 0.07;       
p{2}.nob = 7;                  
p{2}.nobs = 0.7;                 
p{2}.a = 0.02;                
p{2}.as = 0;                   
p{2}.theta = 63*pi/180;       
p{2}.thetas = 15*pi/180;
p{2}.color = [140/255,125/255,40/255];
p{2}.N = 1.5; 
p{2}.sigma = 40*pi/180;   
% 0th Order
p{1}.r = 2;
p{1}.rs = 0.2;
p{1}.lb = 0.7;          
p{1}.lbs = 0.07;             
p{1}.la = 15.7;       
p{1}.las = 1.57;                  
p{1}.ln = 0.7;                 
p{1}.lns = 0.07; 
p{1}.nob = 50;  
p{1}.nobs = 5;   
p{1}.a = 0.03;                 
p{1}.as = 0;                    
p{1}.color = [110/255,100/255,50/255];
p{1}.N = 1.5; 
p{1}.sigma = 15*pi/180;  

dx = 0.35;
root = createBranchedRoot(p, dx); 
n0 = 20;
r0 = 5;
rootsystem = createRootSystem(root,n0,r0); 

days = 25;
steps = 10;
slides = simulate(rootsystem,days,steps,false);
plotTubes(slides{end});

% animate('maize.avi',rootsystem,25,7,[-15,15,-15,15,-35,1,0 1]);


