%
% An individual 0th order root of an idealized Maize root system using the
% same parameters as by Roose, 2001. A plot of the total length of roots of
% every order shows the equivalence to the analytic model.  
%
% See also: Example_Maize
%
% Copyright 2008-2009 Daniel Leitner. See license.txt for details.
%
clear all;

% % 2nd order roots
p{3}.r  = 1.5;       
p{3}.rs = 0;                      
p{3}.k  = 0.1875;                
p{3}.ks = 0;           
p{3}.a  = 5*0.01;            
p{3}.as = 0;                    
p{3}.theta = 60/180*2*pi;      
p{3}.thetas = 0; 
p{3}.color = [200/255,200/255,10/255];  
p{3}.N = 0;                 
p{3}.sigma = pi/10;
% 1st order roots
p{2}.r = 6.4;              
p{2}.rs = 0;
p{2}.lb = 0.7;        
p{2}.lbs = 0;
p{2}.la = 2;          
p{2}.las = 0;                  
p{2}.ln = 0.7;                     
p{2}.lns = 0; 
p{2}.nob = 7;                  
p{2}.nobs = 0;                 
p{2}.a = 5*0.02;               
p{2}.as = 0;                    
p{2}.theta = 60/180*pi;      
p{2}.thetas = 0; 
p{2}.color = [140/255,125/255,40/255];
p{2}.N = 1.5; 
p{2}.sigma = pi/10; 
% 0th Order
p{1}.r = 2;           
p{1}.rs = 0;
p{1}.lb = 0.7;        
p{1}.lbs = 0; 
p{1}.la = 15;         
p{1}.las = 0;
p{1}.ln = 0.7;         
p{1}.lns = 0;     
p{1}.nob = 50;    
p{1}.nobs = 0; 
p{1}.a = 5*0.04;            
p{1}.as = 0;                    
p{1}.color = [110/255,100/255,50/255];
p{1}.N = 0; 
p{1}.sigma = pi/20; 

root = createBranchedRoot(p, [0.5,0.5,0.2] );
rootsystem = createRootSystem(root,1,0,0.5);
slides = simulate(rootsystem,100,100);

%showSlides(slides);
%animate('singleMaize.avi',rootsystem,90,3,getBounds(slides{end}));

l = ones(length(slides),3);
for i=1 :length(slides)
    l(i,:) = getTotal(slides{i},'l',[0, p{3}.a+p{2}.a, p{2}.a+p{1}.a, inf]); %
end
figure;
plot(l); 
hold on;
plot(sum(l,2),'k')
legend('2^{nd} order', '1^{st} order', '0^{th} order', 'total');
legend(2);
xlabel('time (days)')
ylabel('length (cm)')

