%
% The example shows the growth of a single root with no lateral root over
% 100 days and outlines the influence of the spatial discretization.
%
% Copyright 2008-2009 Daniel Leitner. See license.txt for details.
%

clear all;

root.name='G';
k=30;
r=2;
dx=1;
deflect = @(y,dx) ruleGravitropismN(y,0,pi/10,dx);
root.apply = @(x,dt) ruleCreateHighestOrderRoot(x, r, 0, k, 0, 0, 0, 0.1, 0,...
    [ 0 1 0 ], deflect, dx, dt);
  
slides = simulate({root},100,100);
showSlides(slides(1:10:100));

lambda = @(t) k*(1-exp(-(r/k)*t));
for i=1:length(slides)
    l(i) = getTotal(slides{i});
end
figure;
hold on;
plot(l,'r');
plot(lambda(1:1:100),'b');
plot(lambda(1:1:100)-dx,'g');
legend('approximation', 'upper bound \lambda(t)', 'lower bound \lambda(t)-\Delta x');
legend(4);
xlabel('time (days)')
ylabel('length (cm)')
