%
% This example shows six figures from the book "The algorithmic beauty of
% plants". It shows the ability of L-systems to describe self similar
% structures in a compact way.
%
% Copyright 2008-2009 Daniel Leitner. See license.txt for details.
%

clear all;

r = getTurtle();

%
% a
%
r.Plus.delta = 25.7/180*pi;
r.Minus.delta = 25.7/180*pi;
r.F.apply = @(x,dt) {x r.Push r.Plus x r.Pop x r.Push r.Minus x r.Pop x};

new = { r.F };
for i = 1:5
    new = applyRules(new);
end

figure;
plotLines(new);
view(2);

%
% b
%
r.Plus.delta = 20/180*pi;
r.Minus.delta = 20/180*pi;
r.F.apply = @(x,dt) {x r.Push r.Plus x r.Pop x r.Push r.Minus x r.Pop r.Push x r.Pop};

new = { r.F };
for i = 1:5
    new = applyRules(new);
end

figure;
plotLines(new);
view(2);

%
% c
%
r.Plus.delta = 22.5/180*pi;
r.Minus.delta = 22.5/180*pi;
r.F.apply = @(x,dt) {x x r.Minus r.Push r.Minus x r.Plus x r.Plus x r.Pop r.Plus r.Push ...
    r.Plus x r.Minus x r.Minus x r.Pop};

new = { r.F };
for i = 1:4
    new = applyRules(new);
end

figure;
plotLines(new);
view(2);

%
% d
%
r.Plus.delta = 20/180*pi;
r.Minus.delta = 20/180*pi;
X.name = 'X';
r.F.apply = @(x,dt) {x x};
X.apply =  @(x,dt) {r.F r.Push r.Plus x r.Pop r.F r.Push r.Minus x r.Pop r.Plus x };

new = { X };
for i = 1:4
    new = applyRules(new);
end

figure;
plotLines(new);
view(2);

%
% e
%
r.Plus.delta = 25.7/180*pi;
r.Minus.delta = 25.7/180*pi;
r.F.apply = @(x,dt) {x x};
X.name = 'X';
X.apply =  @(x,dt) {r.F r.Push r.Plus x r.Pop r.Push r.Minus x r.Pop r.F x };

new = { X };
for i = 1:4
    new = applyRules(new);
end

figure;
plotLines(new);
view(2);

%
% f
%
r.Plus.delta = 22.5/180*pi;
r.Minus.delta = 22.5/180*pi;
r.F.apply = @(x,dt) {x x};
X.name = 'X';
X.apply =  @(x,dt) {r.F r.Minus r.Push r.Push x r.Pop r.Plus x r.Pop r.Plus r.F ...
    r.Push r.Plus r.F x r.Pop r.Minus x };

new = { X };
for i = 1:4
    new = applyRules(new);
end

figure;
plotLines(new);
view(2);

