function animate(name,str,simtime,movietime,bndaxis)
% animate: Creates an animation and stores it in an .avi movie file.
%
% Parameters:
% name          :filename
% str           :List of L-System letters
% simtime       :simulation time
% movietime     :length of the movie
% (bndaxis)     :spatial bounds of the domain. Default: bndaxis = [-20 20
%       -20 20 -50 0 0 1]
%
% See also: plotTubes.
%
% Copyright 2008-2009 Daniel Leitner. See license.txt for details.
%

if (nargin==4)
    bndaxis = [-20 20 -20 20 -50 0 0 1];
end

FPS = 24;
nof = movietime*FPS;
fpd = nof/simtime;      % fpd... frames per day
dt = 1/fpd;

fig = figure();
frames(1:nof) = getframe(fig);
str = applyRules(str,0);
str = initLabels(str);

aviobj = avifile (name,'compression', 'i420','fps',FPS); %iyuv %i420
close(fig);

active = getActive(str,0);
for i = 1 : nof

    disp([ 'framenumber: ' num2str(i) ', active root tips: ' num2str(length(active))]);

    fig = figure();
    clf;

    [str,active] = applyRules(str,dt,active);

    title(['Time: ' num2str((i/nof)*simtime,2) ' days']);
    daspect([1 1 1])
    set(fig,'Position',[100 100 768 768]) %[100 100 1024 768]
    set(fig,'DoubleBuffer','on');    
    %
    plotTubes(str);
    %
    axis(bndaxis)
    view(0*(i/nof)*360,0); %2*(i/FRAMES)*360, 10, Rotatio  %view(3);
    
    % capture frame
    pause(1);        
    frames(i) = getframe(fig);
    aviobj = addframe ( aviobj, frames(i) );
    close(fig);

end

close(aviobj);

