function [new, na]=applyRules(old,dt,active)
% applyRules: Applies the production rules of an L-System string.
%
% new=applyRules(old)
% old           :L-System string
%
% new=applyRules(old,dt)  (ignores turtle commands)
% old           :L-System string
% dt            :time span
%
% [new,na]=applyRules(old,dt,active) (only active letters)
% old           :list of L-System letters
% dt            :time span
% active        :indices of active letters (e.g.: root tips)
%
% new           :resulting L-System string
% na            :new indices of active letters (only in the 3rd case)
%
% See also: getActive, simulate.
%
% Copyright 2008-2009 Daniel Leitner. See license.txt for details.
%

na=[];
new={};
if (nargin==1)
    for j=1:length(old)
        r = old{j};
        if isfield(r,'apply')
            sr = r.apply(r,1);
        else
            sr = {r};
        end
        new = [new, sr];
    end
end

if (nargin==2)
    rC = 1;
    for j=1:length(old)
        r = old{j};
        switch r.name
            case {'F','#','C','+','-','&','^','\','/','|','[',']','f' }
                new{rC}=r;
                rC=rC+1;
            otherwise
                sr = r.apply(r,dt);
                l = length(sr);
                new(rC:(rC+l-1)) = sr(1:l);
                rC=rC+l;
        end
    end
end

if (nargin==3)
    last = 1;
    c=1;
    for j=1:length(active)
        i = active(j);
        % before index
        new(c:c+(i-1-last)) = old(last:i-1);
        c = c +(i-1-last)+1;
        % replace letter
        r = old{i};
        if (isfield(r,'apply')==0)
            fprintf('no apply field for letter %c index %g',r.name,i);
        end
        sr = r.apply(r,dt);
        l = length(sr);
        if (l>0)
            na = [na, getActive(sr,c-1)];
        end
        new(c:(c+l-1)) = sr(1:l);
        c=c+l;        
        last = i+1;
    end
    % after last index
    i = length(old)+1;
    new(c:c+(i-1-last)) = old(last:i-1);
end

