#include "mex.h"
#include <cmath>

#define p(i,j) p[(i)+np*(j)]
#define x1(i,j) x1[(i)+ns*(j)]
#define x2(i,j) x2[(i)+ns*(j)]

template<class T> inline T sqr(T x) { return x*x; }
template<class T> inline T dot3(T *a,T *b) { return a[0]*b[0]+a[1]*b[1]+a[2]*b[2]; }
template<class T> inline T length(T x,T y,T z) { return sqrt(sqr(x)+sqr(y)+sqr(z)); }

void mexFunction(int nlhs, mxArray *plhs[], int nrhs, const mxArray *prhs[])
{
    int np=mxGetM(prhs[0]);      // number of points
    int ns=mxGetM(prhs[1]);      // number of segments
    double *p=mxGetPr(prhs[0]);
    double *x1=mxGetPr(prhs[1]);
    double *x2=mxGetPr(prhs[2]);
    double *r=mxGetPr(prhs[3]);
    
    plhs[0]=mxCreateDoubleMatrix(np,1,mxREAL);
    double *d=mxGetPr(plhs[0]);
    plhs[1]=mxCreateDoubleMatrix(np,1,mxREAL);
    double *ind=mxGetPr(plhs[1]);
    
    double v[3],w[3];
    double c1,c2,l;
    
    //printf("Points %d , Segments %d",np,ns);
    
    v[0] = x2(0,0)-x1(0,0); v[1]=x2(0,1)-x1(0,1); v[2]=x2(0,2)-x1(0,2);
    
    for (int j=0; j<np; j++) { // points
        
        w[0] = p(j,0)-x1(0,0);  w[1]=p(j,1)-x1(0,1);  w[2]=p(j,2)-x1(0,2) ;
        
        c1=dot3(v,w);
        c2=dot3(v,v);
        
        if (c1<=0)
            d[j] = length(p(j,0)-x1(0,0),p(j,1)-x1(0,1),p(j,2)-x1(0,2))-r[0];
        else if (c1>=c2)
            d[j]=length(p(j,0)-x2(0,0),p(j,1)-x2(0,1),p(j,2)-x2(0,2))-r[0];
        else
            d[j]=length(p(j,0)-(x1(0,0)+c1/c2*v[0]),
            p(j,1)-(x1(0,1)+c1/c2*v[1]),
            p(j,2)-(x1(0,2)+c1/c2*v[2]))-r[0];
        
        ind[j]=1;
        
    }
    
    for (int i=1; i<ns; i++) { //segments
        
        v[0] = x2(i,0)-x1(i,0); v[1]=x2(i,1)-x1(i,1); v[2]=x2(i,2)-x1(i,2);
        
        for (int j=0; j<np; j++) { // points
            
            w[0] = p(j,0)-x1(i,0);  w[1]=p(j,1)-x1(i,1);  w[2]=p(j,2)-x1(i,2) ;
            
            c1=dot3(v,w);
            c2=dot3(v,v);
            
            if (c1<=0)
                l = length(p(j,0)-x1(i,0),p(j,1)-x1(i,1),p(j,2)-x1(i,2))-r[i];
            else if (c1>=c2)
                l = length(p(j,0)-x2(i,0),p(j,1)-x2(i,1),p(j,2)-x2(i,2))-r[i];
            else
                l = length(p(j,0)-(x1(i,0)+c1/c2*v[0]),
                p(j,1)-(x1(i,1)+c1/c2*v[1]),
                p(j,2)-(x1(i,2)+c1/c2*v[2]))-r[i];
            if (l<d[j]) {
                d[j]=l;
                ind[j]=i+1;
            }
        }
    }
    
    
    
}
