function l = getTotal(str, mode, diameters)
% getTotal: Returns the total surface, volume or length of a string.
%
% l = getTotal(str, mode, diameters)
% str          :List of L-System letters
% (mode)       :'v' :volume, 's' :surface, 'l' :length, 'f' :count
%       segments; to exclude dead root segments use capitals and
%       color=[1,1,1]. (defaul mode = 'l').       
% (diameters)  :Vector containg a partition of diameters. Default
%       diameters=[0 inf].
%
% l            :Total surface, volume or length
%
% Copyright 2008-2009 Daniel Leitner. See license.txt for details.
%

if (nargin==1)
    l=0;
    for i=1 : length(str)
        r = str{i};
        if r.name=='F'
            l = l + r.length;
        end
    end
else

    if (nargin<3)
        diameters = [0 inf];
    end

    total=zeros(1,length(diameters)-1);

    wT = 0.1;
    stkPtr = 1;
    cT = [0, 1, 0];
    cT_ = mean(cT);
    for i=1 : length(str)

        cmdT = str{i}.name;

        switch cmdT
            case 'C'
                cT = str{i}.color;
                cT_ = mean(cT);
            case '#'
                wT = str{i}.width;
            case 'F'
                l = str{i}.length;
                switch mode
                    case 'v'
                        v = l*(wT/2)^2*pi; %volume;
                    case 's'
                        v = l*wT*pi; %surface;
                    case 'l'
                        v = l; %length
                    case 'f'
                        v = 1; %number of segments
                    case 'V'
                        if (cT_~=1)
                            v = l*(wT/2)^2*pi; %volume if alive;
                        else
                            v=0;
                        end
                    case 'S'
                        if (cT_~=1)
                            v = l*wT*pi; %surface if alive;
                        else
                            v=0;
                        end
                    case 'L'
                        if (cT_~=1)
                            v = l; %length if alive
                        else
                            v=0;
                        end
                    case 'F'
                        if (cT_~=1)
                            v = 1; %number of segments if alive
                        else
                            v=0;
                        end
                end
                l=length(diameters(diameters<=wT));
                if (l>0 && l<=length(total))
                    total(l) = total(l) + v;
                end
            case '[' %push
                stack(stkPtr).wT = wT ;
                stkPtr = stkPtr +1 ;
            case ']' %pop
                stkPtr = stkPtr -1 ;
                wT = stack(stkPtr).wT ;
        end

    end

    l=total;

end





