function plotTubes(lines,widths,colors,Nsides)
% plotTubes: Plots a roots system using Matlab stream tubes
%
% plotTubes(str)
% str             :L-System string
%
% plotTubes(lines,widths,colors,Nsides)
% lines           :a list of polylines given by a vector of points
% width           :a list of diameters.
% colors          :a list of colors
% (Nsides)        :The number of points along the circumference of the
%       tube. Default Nsides=7.
%        
% See also: streamtubes, getPolyline.
%
% Copyright 2008-2009 Daniel Leitner. See license.txt for details.
% 

if (nargin==1)
    [lines,widths,colors] = getPolylines(lines);
end

if (nargin<4)
    Nsides=7;
end

hsF=streamtube(lines,widths,[1,Nsides]);

% delete empty
c=0;
for i = 1 : length(widths)
    if (length(widths{i})==1)
        colors(i-c)=[];
        c=c+1;
    end
end

% draw tubes
for i=1 : length(hsF)
    hsfp{i} = get(hsF(i));
    nodes = size(hsfp{i}.ZData,1);
    c = colors{i};
    cd = cat(3,c(1)*ones(nodes,Nsides+1),c(2)*ones(nodes,Nsides+1),c(3)*ones(nodes,Nsides+1));
    set(hsF(i),'cdata',cd)
end

axis equal;
bnd = getBounds([],lines);
bnd = bnd + [0,0.01,0,0.01,0,0.01,0,0]; 
axis(bnd);
view(0,0)
shading interp;
camlight;
lighting gouraud;
rotate3d on


