function new = ruleBoundDeflection(y,dx,dfunc,deflection)
% ruleBoundDeflection: Bounds a deflection rule.
%
% Parametrs:
% y          :labeled lettter (containg position, heading, color and width)
% dx         :next segments length 
% dfunc      :distance function that bounds the domain
% deflection :deflection rule (e.g. ruleGravitropism)
%
% new       :resulting string containing rotations
%
% See also: Example_Bounds, ruleGravitropism
%
% Copyright 2008-2009 Daniel Leitner. See license.txt for details.
%

word = deflection(y,dx);
%Evaluate result
alpha=0;
beta=0;
if length(word)==2
    beta = word{1}.delta;
    alpha = word{2}.delta;
elseif length(word)==1
    if (word{1}.name=='\')
        beta=word{1}.delta;
    elseif (word{1}.name=='+')
        alpha=word{1}.delta;
    else
        disp('Unexpected result from deflection');
    end
elseif isempty(word)
    %ok
else
    disp('Unexpected result from deflection');
end

d = dfunc(testAlphaBeta(alpha,beta,y,dx));

i=0;
dmin=inf;
while (d>0)
    i=i+1;
    %try beta
    j=0;
    while d>0 && j<5;
        beta = 2*pi*rand;
        d = dfunc(testAlphaBeta(alpha,beta,y,dx));
        if (d<dmin)
            dmin=d;
            bestA = alpha;
            bestB = beta;
        end
        j=j+1;
    end
    %increase alpha
    if d>0
        alpha=alpha + pi/20*alpha/abs(alpha);
    end
    if i>20
        disp('Could not respect boundaries');
        disp(dmin);
        alpha=bestA;
        beta=bestB;
        break
    end
end

% Create rules
new = {};
if (alpha~=0)
    if (beta~=0)
        r.name = '\';
        r.delta = beta;
        new = [new,{r}];
    end
    t.name = '+';
    t.delta = alpha;
    new = [new,{t}];
end


function x=testAlphaBeta(alpha,beta,y,dx)
alpha=-alpha;
R=y.R;
%roll left
Rhp = [  1     0     0; ...
    0 cos(beta) -sin(beta) ;...
    0 sin(beta)  cos(beta) ] ;
R2 = R * Rhp;
%turn
Rum = [    cos(-alpha) sin(-alpha) 0;...
    -sin(-alpha) cos(-alpha) 0; ...
    0       0      1];
R = R2 * Rum;
x=ones(1,3);
x(1,1) = y.xT + dx*R(1,1);
x(1,2) = y.yT + dx*R(2,1);
x(1,3) = y.zT + dx*R(3,1);


