function new = ruleBranch(x,lambda,times,delays,branch,next,deflect,dx,dt)
% ruleBranch: Production rule for the branching zone of a root.
%
% Parameters:
% x         :letter that is replaced by the production rule
% -> x.c    :number of branches
% lambda    :growth function lambda
% times     :creation and terminal times of branches 
% delays    :delay times for delayed growth of branches
% branch    :initial string containing a branch
% next      :successive string (after the branching zone)
% deflect   :production rule for root tip deflection
% dx        :spatial discretization along the root
% dt        :time step
%
% new       :resulting string
%
% See also: ruleCreateRoot, createBranchedRoot.
%
% Copyright 2008-2009 Daniel Leitner. See license.txt for details.
%

x.c=x.c+1;
nob = length(delays);

% Segment
s.name = 'G';
s.t = 0;
s.l = 0;
if isfield(x,'xT') %label
    s.xT = x.xT;
    s.yT = x.yT;
    s.zT = x.zT;
    s.wT = x.wT;
    s.cT = x.cT;
    s.R = x.R;
end
if (x.c<nob)
    % zeit mitgeben
    s.apply = @(y,dt) ruleSectionGrowth(y,lambda,...
        lambda(times(x.c),s),lambda(times(x.c+1),s), times(x.c),times(x.c+1),x,deflect,dx,dt);
else
    s.apply = @(y,dt) ruleSectionGrowth(y,lambda,...
        lambda(times(x.c),s),lambda(times(x.c+1),s), times(x.c),times(x.c+1),next,deflect,dx,dt);
end

% Delayed Branch
delay.name='w';
delay.t = 0;
delay.apply = @(y,dt) ruleDelay(y,delays(x.c),branch,dt);
if isfield(x,'xT')
    delay.xT = x.xT;
    delay.yT = x.yT;
    delay.zT = x.zT;
    delay.wT = x.wT;
    delay.cT = x.cT;
    delay.R = x.R;
end

delay = delay.apply(delay,dt);
s = s.apply(s,dt);

new = [delay, s];




