function str = writeString(string, mode)
% writeString: Creates a string containing the names of L-System letters
%
% Parameters:
% string        :List of L-System leters
% mode          :'N' names of letters, 'S' structure, lengthes between
%           branching points, 'T' ages between branching points (default =
%           'N')
%
% str           :String containing the names of the letters
%
% Copyright 2008-2009 Daniel Leitner. See license.txt for details.
%

if (nargin<2)
    mode = 'N';
end

switch mode
    case 'N'
        str = [];
        for i = 1 : length(string)
            if isfield(string{i},'name')
                str = [str, string{i}.name];
            else
                str = [str, '!'];
            end
        end
    case 'S'
        l=0;
        for i=1 : length(string)
            cmdT = string{i}.name;
            switch cmdT
                case 'F'
                    l=l+string{i}.length;
                case '[' %push
                    fprintf(' %g [',l);
                    l = 0;
                case ']' %pop
                    fprintf('%g]',l);
                    l=0;
            end
        end
        fprintf('\n');
    case 'T'
        t=0;
        first = 1;
        for i=1 : length(string)
            cmdT = string{i}.name;
            switch cmdT
                case 'F'
                    if isfield(string{i},'time')
                        t = string{i}.time;
                        if first
                            fprintf(' %g-',t);
                            first=0;
                        end
                    end                    
                case '[' %push
                    fprintf('%g [',t);
                    first = 1;
                case ']' %pop
                    fprintf('%g]',t);
                    first = 1;
            end
        end
        fprintf('\n');
end


